@@ -58,7 +58,7 @@ class Default(objects.Object):
 cache = Default()
 
 # the webserver cache object class.
-class WebServer(syst3m.objects.Thread):
+class WebServer(objects.Thread):
 	def __init__(self,
 		id="webserver",
 		host="127.0.0.1",
@@ -66,7 +66,7 @@ class WebServer(syst3m.objects.Thread):
 		path=None,
 		default={},
 	):
-		syst3m.objects.Thread.__init__(self)
+		objects.Thread.__init__(self)
 		self.__cache__ = Default(path=path)
 		self.assign({
 			"sleeptime":3,
@@ -76,22 +76,24 @@ class WebServer(syst3m.objects.Thread):
 			"cache":default,
 		})
 	def set(self, group=None, id=None, value=None):
-		response = requests.get(f'http://{self.host}:{self.port}/set?{urllib.parse.urlencode({
+		encoded = urllib.parse.urlencode({
 			"key":key,
 			"id":id,
 			"value":value,
 			"token":self.token(),
-		})}')
+		})
+		response = requests.get(f'http://{self.host}:{self.port}/set?{encoded}')
 		try:
 			response = response.json()
 		except:
 			return r3sponse.error_response(f"Failed to serialize output: {response}, status code {response.status_code}")
 		return r3sponse.ResponseObject(response)
 	def get(self, group=None, id=None):
-		response = requests.get(f'http://{self.host}:{self.port}/get?{urllib.parse.urlencode({
+		encoded = urllib.parse.urlencode({
 			"key":key,
 			"token":self.token(),
-		})}')
+		})
+		response = requests.get(f'http://{self.host}:{self.port}/get?{encoded}')
 		try:
 			response = response.json()
 		except:
@@ -146,10 +148,11 @@ class WebServer(syst3m.objects.Thread):
 			self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
 		return self.__cache__.get(group=self.id, id="token")
 	def running(self):
-		response = requests.get(f'http://{self.host}:{self.port}/active?{urllib.parse.urlencode({
+		encoded = urllib.parse.urlencode({
 			"key":key,
 			"token":self.token(),
-		})}')
+		})
+		response = requests.get(f'http://{self.host}:{self.port}/active?{encoded}')
 		#try:
 		response = response.json()
 		#except:
